@@ -90,9 +90,9 @@ DEFAULT_PLATFORM_DB = {
         u"0455": u"MTB_UBLOX_NINA_B1",
         u"0456": u"MTB_MURATA_ABZ",
         u"0457": u"MTB_RAK811",
-        u"0458": u"MTB_ADV_WISE_1510",
-        u"0459": u"MTB_ADV_WISE_1530",
-        u"0460": u"MTB_ADV_WISE_1570",
+        u"0458": u"ADV_WISE_1510",
+        u"0459": u"ADV_WISE_1530",
+        u"0460": u"ADV_WISE_1570",
         u"0461": u"MTB_LAIRD_BL652",
         u"0462": u"MTB_USI_WM_BN_BM_22",
         u"0465": u"MTB_LAIRD_BL654",
@@ -294,13 +294,12 @@ DEFAULT_PLATFORM_DB = {
         u"5004": u"ARM_CM3DS_MPS2",
         u"5005": u"ARM_MPS2_M0DS",
         u"5006": u"ARM_MUSCA_A1",
-        u"5007": u"ARM_MPS2_M1",
-        u"5009": u"ARM_MPS2_M3",
-        u"5011": u"ARM_MPS2_M4",
-        u"5015": u"ARM_MPS2_M7",
+        u"5007": u"ARM_MUSCA_B1",
+        u"5009": u"ARM_MUSCA_S1",
         u"5020": u"HOME_GATEWAY_6LOWPAN",
         u"5500": u"RZ_A1H",
         u"5501": u"GR_LYCHEE",
+        u"5502": u"GR_MANGO",
         u"6000": u"FUTURE_SEQUANA",
         u"6660": u"NZ32_SC151",
         u"7011": u"TMPM066",
